@@ -6,8 +6,9 @@
 #' returns the frequency, cumulative frequency, frequency percent and cumulative
 #' frequency percent. \code{barplot.ds_freq_table} creates bar plot for the
 #' frequency table created using \code{ds_freq_table}
-#' @param data numeric or factor vector
-#' @param height an object of class \code{ds_freq_table}
+#' @param data a \code{data.frame} or a \code{tibble}
+#' @param variable column in \code{data}
+#' @param x an object of class \code{ds_freq_table}
 #' @param ... further arguments to be passed to or from methods
 #' @return \code{ds_freq_table} returns an object of class \code{"ds_freq_table"}.
 #' An object of class \code{"ds_freq_table"} is a list containing the
@@ -19,38 +20,43 @@
 #' \code{freq_table()} has been deprecated. Instead use \code{ds_freq_table()}.
 #' @examples
 #' # frequency table
-#' mt <- mtcars
-#' mt$cyl <- as.factor(mt$cyl)
-#' ds_freq_table(mt$cyl)
+#' ds_freq_table(mtcarz, cyl)
 #'
 #' # barplot
-#' mt <- mtcars
-#' mt$cyl <- as.factor(mt$cyl)
-#' k <- ds_freq_table(mt$cyl)
-#' barplot(k)
+#' k <- ds_freq_table(mtcarz, cyl)
+#' plot(k)
 #' @seealso \code{link{ds_freq_cont}} \code{link{ds_cross_table}}
 #' @export
 #'
-ds_freq_table <- function(data) UseMethod("ds_freq_table")
+ds_freq_table <- function(data, variable) UseMethod("ds_freq_table")
 
 #' @export
-ds_freq_table.default <- function(data) {
+ds_freq_table.default <- function(data, variable) {
+  varyable <- enquo(variable)
 
-  if (!is.factor(data)) {
-    stop('data must be categorical/qualitative')
+  fdata <-
+    data %>%
+    pull(!! varyable) %>%
+    na.omit()
+
+  if (!is.factor(fdata)) {
+    stop("variable must be categorical/qualitative")
   }
 
-  var_name = l(deparse(substitute(data)))
-  data <- na.omit(data)
-  level_names <- levels(data)
-  data_len <- length(data)
+  var_name <-
+    data %>%
+    select(!! varyable) %>%
+    names()
+
+  level_names <- levels(fdata)
+  data_len <- length(fdata)
 
   # unique values in the input
-  cq <- forcats::fct_unique(data)
+  cq <- forcats::fct_unique(fdata)
 
   # count of unique values in the input
-  result <- data %>%
-    fct_count %>%
+  result <- fdata %>%
+    fct_count() %>%
     pull(2)
 
   # length of result
@@ -66,21 +72,23 @@ ds_freq_table.default <- function(data) {
   cum_per <- percent(cum, data_len)
 
   # matrix
-  ftable <- tibble(Levels = level_names,
-                   Frequency = result,
-                   `Cum Frequency` = cum,
-                   Percent = per,
-                   `Cum Percent` = cum_per)
+  ftable <- tibble(
+    Levels = level_names,
+    Frequency = result,
+    `Cum Frequency` = cum,
+    Percent = per,
+    `Cum Percent` = cum_per
+  )
 
 
   result <- list(
     ftable = ftable,
-    varname = var_name
+    varname = var_name,
+    data = data
   )
 
   class(result) <- "ds_freq_table"
   return(result)
-
 }
 
 #' @export
@@ -88,10 +96,7 @@ ds_freq_table.default <- function(data) {
 #' @usage NULL
 #'
 freq_table <- function(data) {
-
   .Deprecated("ds_freq_table()")
-  ds_freq_table(data)
-
 }
 
 #' @export
@@ -100,21 +105,33 @@ print.ds_freq_table <- function(x, ...) {
 }
 
 
-
+#' @importFrom ggplot2 ylab
 #' @rdname ds_freq_table
 #' @export
 #'
-barplot.ds_freq_table <- function(height, ...) {
-    j <- as.numeric(height$ftable[[2]])
-    h <- j
-    ymax <- max(h)
-    cols <- length(j)
-    x_names <- height$ftable[[1]]
-    k <- barplot(j, col = topo.colors(cols),
-                 main = paste('Bar Plot of', height$varname),
-                 xlab = height$varname,
-                 ylab = 'Frequency',
-                 ylim = c(0, ymax[1]),
-                 names.arg = x_names)
-    graphics::text(k, h, labels = j, adj = 0.5, pos = 1)
+plot.ds_freq_table <- function(x, ...) {
+  x_lab <-
+    x %>%
+    use_series(varname) %>%
+    extract(1)
+
+  k <-
+    x %>%
+    use_series(varname) %>%
+    extract(1) %>%
+    sym()
+
+  p <-
+    x %>%
+    use_series(data) %>%
+    select(x = !! k) %>%
+    ggplot() +
+    geom_bar(aes(x = x), fill = "blue") +
+    xlab(x_lab) + ylab("Count") +
+    ggtitle(paste("Bar plot of", x_lab))
+
+  print(p)
+
+  result <- list(plot = p)
+  invisible(result)
 }
