@@ -10,9 +10,13 @@ library(tools)
 library(lubridate)
 library(scales)
 library(stringr)
+library(rlang)
+library(ggplot2)
+library(forcats)
+
 
 shinyServer(function(input, output, session) {
-    
+
     source("logic/logic_dataoptions.R", local = T)
     source("logic/logic_upload.R", local = T)
     source("logic/logic_transform2.R", local = T)
@@ -33,7 +37,7 @@ shinyServer(function(input, output, session) {
     source("logic/logic_norm.R", local = T)
     source("logic/logic_chisq.R", local = T)
     source("logic/logic_home.R", local = T)
-    
+
 })
 
 
